@@ -43,7 +43,6 @@ NULL
 #' @author N. Frerebeau
 #' @family classes
 #' @family calendar classes
-#' @family gregorian era classes
 #' @docType class
 #' @aliases GregorianCalendar-class
 #' @keywords internal
@@ -58,127 +57,6 @@ NULL
   contains = "TimeScale"
 )
 
-#' BP
-#'
-#' An S4 class to represent the (Gregorian) BP era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases BP-class
-#' @keywords internal
-.BP <- setClass(
-  Class = "BP",
-  prototype = list(
-    label = "BP",
-    name = "Before Present",
-    epoch = 1950,
-    direction = -1L
-  ),
-  contains = "GregorianCalendar"
-)
-
-#' b2k
-#'
-#' An S4 class to represent the (Gregorian) b2k era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases b2k-class
-#' @keywords internal
-.b2k <- setClass(
-  Class = "b2k",
-  prototype = list(
-    label = "b2k",
-    name = "Before 2000",
-    epoch = 2000,
-    direction = -1L
-  ),
-  contains = "GregorianCalendar"
-)
-
-#' BC
-#'
-#' An S4 class to represent the (Gregorian) BC era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases BC-class
-#' @keywords internal
-.BC <- setClass(
-  Class = "BC",
-  prototype = list(
-    label = "BC",
-    name = "Before Christ",
-    direction = -1L
-  ),
-  contains = "GregorianCalendar"
-)
-
-#' BCE
-#'
-#' An S4 class to represent the (Gregorian) BCE era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases BCE-class
-#' @keywords internal
-.BCE <- setClass(
-  Class = "BCE",
-  prototype = list(
-    label = "BCE",
-    name = "Before Common Era",
-    direction = -1L
-  ),
-  contains = "GregorianCalendar"
-)
-
-#' AD
-#'
-#' An S4 class to represent the (Gregorian) AD era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases AD-class
-#' @keywords internal
-.AD <- setClass(
-  Class = "AD",
-  prototype = list(
-    label = "AD",
-    name = "Anno Domini"
-  ),
-  contains = "GregorianCalendar"
-)
-
-#' CE
-#'
-#' An S4 class to represent the (Gregorian) CE era.
-#' @author N. Frerebeau
-#' @family classes
-#' @family gregorian era classes
-#' @docType class
-#' @aliases CE-class
-#' @keywords internal
-.CE <- setClass(
-  Class = "CE",
-  prototype = list(
-    label = "CE",
-    name = "Common Era"
-  ),
-  contains = "GregorianCalendar"
-)
-
-# .GregorianCalendar(
-#   label = "AUC",
-#   name = "Ab urbe condita",
-#   epoch = 753,
-#   direction = 1
-# )
-
 ## Julian TimeScale ------------------------------------------------------------
 #' JulianCalendar
 #'
